@@ -21,7 +21,8 @@ class PoolDetails:
     #: One pair of tokens
     token1: TokenDetails
 
-    #: Pool fee in BPS
+    #: Pool fee as expressed in smart contracts (100*bps)
+    #: e.g. 0.3% = 30bps so raw_fee = 3000
     raw_fee: int
 
     #: Pool fee as % multiplier, 1 = 100%
@@ -65,3 +66,18 @@ def fetch_pool_details(web3, pool_contact_address: Union[str, HexAddress]) -> Po
         raw_fee,
         raw_fee / 1_000_000,
     )
+
+
+def get_raw_fee_from_pool_address(web3, pool_contract_address: HexAddress):
+    """Get the swap fee for a pool, given the pool contract address
+
+    :param web3:
+        Web3 instance
+
+    :param pool_contract_address:
+        Address of pool contract
+
+    :return:
+        Swap fee expressed as uint24"""
+    pool = get_deployed_contract(web3, "uniswap_v3/UniswapV3Pool.json", pool_contract_address)
+    return pool.functions.fee().call()
